@@ -243,13 +243,16 @@ class TestDataTypes(BaseTest):
         l0 = create('file:///etc/test')
         self.ae(l0.url_start_at(0), 0)
 
-        for trail in '.,]>)\\':
+        for trail in '.,\\':
             lx = create("http://xyz.com" + trail)
             self.ae(lx.url_end_at(0), len(lx) - 2)
+        for trail in ')}]>':
+            lx = create("http://xyz.com" + trail)
+            self.ae(lx.url_end_at(0), len(lx) - 1)
         l0 = create("ftp://abc/")
         self.ae(l0.url_end_at(0), len(l0) - 1)
         l2 = create("http://-abcd] ")
-        self.ae(l2.url_end_at(0), len(l2) - 3)
+        self.ae(l2.url_end_at(0), len(l2) - 2)
         l3 = create("http://ab.de           ")
         self.ae(l3.url_start_at(4), 0)
         self.ae(l3.url_start_at(5), 0)
@@ -354,11 +357,18 @@ class TestDataTypes(BaseTest):
     def test_utils(self):
         def w(x):
             return wcwidth(ord(x))
+        self.ae(wcswidth('a\033[2mb'), 2)
+        self.ae(wcswidth('\033a\033[2mb'), 2)
+        self.ae(wcswidth('a\033]8;id=moo;https://foo\033\\a'), 2)
+        self.ae(wcswidth('a\033x'), 2)
         self.ae(tuple(map(w, 'a1\0コニチ ✔')), (1, 1, 0, 2, 2, 2, 1, 1))
         self.ae(wcswidth('\u2716\u2716\ufe0f\U0001f337'), 5)
-        self.ae(wcswidth('\033a\033[2mb'), 2)
         self.ae(wcswidth('\u25b6\ufe0f'), 2)
         self.ae(wcswidth('\U0001f610\ufe0e'), 1)
+        self.ae(wcswidth('\U0001f1e6a'), 3)
+        self.ae(wcswidth('\U0001F1E6a\U0001F1E8a'), 6)
+        self.ae(wcswidth('\U0001F1E6\U0001F1E8a'), 3)
+        self.ae(wcswidth('\U0001F1E6\U0001F1E8\U0001F1E6'), 4)
         # Regional indicator symbols (unicode flags) are defined as having
         # Emoji_Presentation so must have width 2
         self.ae(tuple(map(w, '\U0001f1ee\U0001f1f3')), (2, 2))
